@@ -1,7 +1,7 @@
 // pstable.h				emacs, this is written in -*-c++-*-
 //
 // This program is free software. See the file COPYING for details.
-// Author: Mattias Engdegrd, 1997, 1998
+// Author: Mattias Engdegrd, 1997-1999
 
 #ifndef PSTABLE_H
 #define PSTABLE_H
@@ -13,17 +13,21 @@ class Pstable : public HeadedTable
 {
     Q_OBJECT
 public:
-    Pstable(QWidget *parent, Procview *pv);
+    Pstable(QWidget *parent);
 
-    void recompute_table_widths(int changed_col = -1);
+    void recompute_table_widths();
     void repaint_changed();
-    void repaint_statically_changed(int update_col);
     void transfer_selection();
     void set_sortcol();
+    void setProcview(Procview *pv);
+    void setRows();
+    void set_initial_mode(bool treemode);
+    void set_mode(bool treemode);
 
 public slots:
-    void selection_update(int row);
+    void selection_update(const Svec<int> *row);
     void sortcol_change(int col);
+    void subtree_folded(int row);
 
 signals:
     void selection_changed();
@@ -36,10 +40,15 @@ protected:
     virtual int alignment(int col);
     virtual int leftGap(int col);
     virtual QString tipText(int col);
+    virtual int rowDepth(int row);
+    virtual NodeState folded(int row);
+    virtual int parentRow(int row);
+    virtual bool lastChild(int row);
 
 private:
     Procview *procview;
-    int leftmostchanged;	// leftmost col whose width changed, or -1
+    int leftmostchanged;	// leftmost (physical) col whose width changed,
+				// or -1
 };
 
 #endif // PSTABLE_H
